@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_admin_errata == "NO") {
@@ -29,9 +29,11 @@ if ($pass_admin_errata == "NO") {
 $voto_tot = "";
 $voto_giornale = "";
 $punti_tot = "";
+$num2 = 0;
+$num_giornata = substr($giornata,8);
 
 # prendo i voti dal file
-$voti = file("$giornata/voti.txt");
+$voti = file("dati/voti$num_giornata.txt");
 $num_voti = count($voti);
 for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
 $dati_voto = explode($separatore_campi_file_voti, $voti[$num1]);
@@ -41,6 +43,25 @@ $voto_giornale[$num_calciatore] = $dati_voto[($num_colonna_votogiornale_file_vot
 } # fine for $num1
 
 
+$file_giornata = file("dati/$giornata");
+$num_linee_file_giornata = count($file_giornata);
+for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
+$linea = substr($file_giornata[$num1],0,-1);
+if ($linea == "#@& fine formazioni #@&") break;
+if ($linea == "#@& formazione #@&") $giocatore = "";
+if ($giocatore) {
+${$formazione}[$num2] = $file_giornata[$num1];
+$num2++;
+} # fine if ($giocatore)
+if ($aggiorna_giocatore) {
+$giocatore = $linea;
+$formazione = "formazione_$giocatore";
+$num2 = 0;
+$aggiorna_giocatore = "";
+} # fine if ($aggiorna_giocatore)
+if ($linea == "#@& formazione #@&") $aggiorna_giocatore = "SI";
+} # fine for $num1
+
 $num_giocatori=count($pass);
 reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
@@ -51,15 +72,15 @@ $sostituisci_D = 0;
 $sostituisci_C = 0;
 $sostituisci_A = 0;
 $punti_tot[$giocatore] = 0;
-$formazione = file("$giornata/formazione_$giocatore");
-$num_linee_formazione = count($formazione);
+$formazione = "formazione_$giocatore";
+$num_linee_formazione = count($$formazione);
 
 # punteggio dei titolari
 for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
-if (!$formazione[$num2]) break;
-if ($formazione[$num2] == "
+if (!${$formazione}[$num2]) break;
+if (${$formazione}[$num2] == "
 ") break;
-$dati_calciatore = explode(",", $formazione[$num2]);
+$dati_calciatore = explode(",", ${$formazione}[$num2]);
 $num_calciatore = $dati_calciatore[0];
 if ($voto_tot[$num_calciatore] == 0 and $voto_giornale[$num_calciatore] == 0) {
 $ruolo_calc = $dati_calciatore[2];
@@ -70,10 +91,10 @@ $$nome_sostituisci++;
 } # fine if ($voto_tot[$num_calciatore] == 0 and...
 else {
 $nome_calc = $dati_calciatore[1];
-$formazione[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",$formazione[$num2]);
-$formazione[$num2] = ereg_replace("
-","",$formazione[$num2]);
-$formazione[$num2] .= ",".$voto_tot[$num_calciatore]."
+${$formazione}[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
+${$formazione}[$num2] = ereg_replace("
+","",${$formazione}[$num2]);
+${$formazione}[$num2] .= ",".$voto_tot[$num_calciatore]."
 ";
 $punti_tot[$giocatore] = $punti_tot[$giocatore] + $voto_tot[$num_calciatore];
 } # fine else if ($voto_tot[$num_calciatore] == 0 and...
@@ -81,59 +102,72 @@ $punti_tot[$giocatore] = $punti_tot[$giocatore] + $voto_tot[$num_calciatore];
 
 # punteggio dei panchinari
 for ($num2 = ($num2 + 1) ; $num2 < $num_linee_formazione; $num2++) {
-if (!$formazione[$num2]) break;
-if ($formazione[$num2] == "
+if (!${$formazione}[$num2]) break;
+if (${$formazione}[$num2] == "
 ") break;
-$dati_calciatore = explode(",", $formazione[$num2]);
+$dati_calciatore = explode(",", ${$formazione}[$num2]);
 $num_calciatore = $dati_calciatore[0];
 if ($voto_tot[$num_calciatore] != 0 or $voto_giornale[$num_calciatore] != 0) {
 $ruolo_calc = $dati_calciatore[2];
 $ruolo_calc = ereg_replace("
 ","",$ruolo_calc);
 $nome_sostituisci = "sostituisci_$ruolo_calc";
-$formazione[$num2] = ereg_replace("
-","",$formazione[$num2]);
-$formazione[$num2] .= ",".$voto_tot[$num_calciatore]."
+${$formazione}[$num2] = ereg_replace("
+","",${$formazione}[$num2]);
+${$formazione}[$num2] .= ",".$voto_tot[$num_calciatore]."
 ";
 if ($$nome_sostituisci >= 1) {
 $nome_calc = $dati_calciatore[1];
-$formazione[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",$formazione[$num2]);
+${$formazione}[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
 $punti_tot[$giocatore] = $punti_tot[$giocatore] + $voto_tot[$num_calciatore];
 $$nome_sostituisci = $$nome_sostituisci - 1;
 } # fine if ($$nome_sostituisci >= 1)
 } # fine if ($voto_tot[$num_calciatore] != 0 or...
 } # fine for $num2
 
-# riscrivo la formazione con i voti
-$lock = fopen("adnin.lock","w+");
-flock($lock,2);
-$fileformazione = fopen("$giornata/formazione_$giocatore","w+");
-flock($fileformazione,2);
-rewind($fileformazione);
-for ($num2 = 0 ; $num2 < $num_linee_formazione ; $num2++) {
-fwrite($fileformazione,$formazione[$num2]);
-} # fine for $num1
-flock($fileformazione,3);
-flock($lock,3);
 echo "$giocatore: ".$punti_tot[$giocatore]."<br>";
 next($pass);
 } # fine for $num1
 
 
-$lock = fopen("adnin.lock","w+");
+# riscrivo le formazioni con i voti e i punteggi alla fine
+$lock = fopen("dati/admin.lock","w+");
 flock($lock,2);
-$filepunteggi = fopen("$giornata/punteggi.txt","w+");
-flock($filepunteggi,2);
-rewind($filepunteggi);
+$filegiornata = fopen("dati/$giornata","w+");
+flock($filegiornata,2);
+rewind($filegiornata);
 reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
 $giocatore = key($pass);
-fwrite($filepunteggi,"$giocatore,".$punti_tot[$giocatore]."
+fwrite($filegiornata,"#@& formazione #@&
+$giocatore
+");
+$formazione = "formazione_$giocatore";
+$formazione = $$formazione;
+$num_linee_formazione = count($formazione);
+for ($num2 = 0 ; $num2 < $num_linee_formazione ; $num2++) {
+fwrite($filegiornata,$formazione[$num2]);
+} # fine for $num2
+next($pass);
+} # fine for $num1
+fwrite($filegiornata,"#@& fine formazioni #@&
+");
+
+fwrite($filegiornata,"#@& punteggi #@&
+");
+reset($pass);
+for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
+$giocatore = key($pass);
+fwrite($filegiornata,"$giocatore,".$punti_tot[$giocatore]."
 ");
 next($pass);
 } # fine for $num1
-flock($filepunteggi,3);
+fwrite($filegiornata,"#@& fine punteggi #@&
+");
+flock($filegiornata,3);
+fclose($filegiornata);
 flock($lock,3);
+fclose($lock);
 
 echo "<form method=\"post\" action=\"giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
@@ -144,5 +178,5 @@ echo "<form method=\"post\" action=\"giornata.php\">
 
 } # fine if ($pass_admin_errata == "NO")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
