@@ -1,8 +1,8 @@
 <?php
 
-###############################################################################
+#################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
@@ -32,10 +32,10 @@ $soldi_spesi = 0;
 $vecchio_proprietario = "";
 $nuovo_costo = "";
 $num_calciatori_posseduti = 0;
-$lock = fopen("mercato.lock","w+");
+$lock = fopen("dati/mercato.lock","w+");
 flock($lock,2);
 
-$calciatori = @file("mercato.txt");
+$calciatori = @file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -67,7 +67,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) {
 $inserire = "NO";
 $frase .= "Tempo scaduto per questa offerta!<br>";
@@ -83,7 +83,7 @@ $frase .= "L'offerta non  abbastanza alta per comprare il calciatore.<br>";
 
 if ($trovato != "SI") {
 $sostituire = "NO";
-$calciatori_completi = file("calciatori.txt");
+$calciatori_completi = file("dati/calciatori.txt");
 $num_calciatori_completi = count($calciatori_completi);
 for ($num1 = 0 ; $num1 < $num_calciatori_completi ; $num1++) {
 $dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori_completi[$num1]);
@@ -119,7 +119,7 @@ $frase .= "L'offerta deve essere un numero intero.<br>";
 } # fine if ($verifica_num != "")
 
 $num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
-$surplus = @file("squadra_$nome_utente");
+$surplus = @file("dati/squadra_$nome_utente");
 $surplus = $surplus[0];
 if ($vecchio_proprietario == $nome_utente and $vecchio_proprietario != $proprietario_vero) {
 $surplus = $surplus - $costo + $vecchio_costo;
@@ -141,13 +141,18 @@ if ($sostituire == "NO") {
 $posizione == 0;
 $num_calciatori++;
 } # fine if ($sostituire == "NO")
-$file_mercato = fopen("mercato.txt","w+");
+$file_mercato = fopen("dati/mercato.txt","w+");
 flock($file_mercato,2);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 
 if ($posizione == $num1) {
-$adesso = date("YmdHi");
-$linea = "$num_calciatore,$nome,$ruolo,$valore_offerta,$nome_utente,$adesso";
+$anno_attuale = date("Y");
+$mese_attuale = date("m");
+$giorno_attuale = date("d");
+$ora_attuale = date("H");
+$minuto_attuale = date("i");
+$scadenza = date("YmdHi",mktime($ora_attuale+$aspetta_ore,$minuto_attuale+$aspetta_minuti,0,$mese_attuale,$giorno_attuale+$aspetta_giorni,$anno_attuale));
+$linea = "$num_calciatore,$nome,$ruolo,$valore_offerta,$nome_utente,$scadenza";
 
 if ($vecchio_proprietario) {
 $linea .= ",$vecchio_proprietario,$vecchio_costo";
@@ -161,10 +166,10 @@ $aggiungi_surplus = $valore_offerta - $vecchio_costo;
 } # fine if ($vecchio_proprietario == $proprietario_vero)
 else { $aggiungi_surplus = $valore_offerta - $costo; }
 } # fine else if ($vecchio_proprietario == $nome_utente)
-$lockutente = fopen("squadra_$vecchio_proprietario.lock","w+");
+$lockutente = fopen("dati/squadra_$vecchio_proprietario.lock","w+");
 flock($lockutente,2);
-$linee = @file("squadra_$vecchio_proprietario");
-$filesquadra = fopen("squadra_$vecchio_proprietario","w+");
+$linee = @file("dati/squadra_$vecchio_proprietario");
+$filesquadra = fopen("dati/squadra_$vecchio_proprietario","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
