@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 
 if ($cambia_pass) {
@@ -33,10 +33,10 @@ $cambiare = "NO";
 } # fine if ($nuova_pass1 != $nuova_pass2 and ...)
 
 if ($cambiare != "NO") {
-$lock = fopen("pass.lock","w+");
+$lock = fopen("dati/pass.lock","w+");
 flock($lock,2);
-$linee_pass = file("dati.php");
-$filepass = fopen("dati.php","w+");
+$linee_pass = file("dati/dati.php");
+$filepass = fopen("dati/dati.php","w+");
 flock($filepass,2);
 $num_linee_pass = count($linee_pass);
 $lung_nome_utente = strlen($nome_utente) + 1;
@@ -76,7 +76,7 @@ echo "<form method=\"post\" action=\"login.php\">
 
 else {
 
-include("dati.php");
+include("dati/dati.php");
 $pass = "";
 $passadmin = "";
 
@@ -90,8 +90,9 @@ echo "<form method=\"post\" action=\"guarda_giornata.php\">
  n <select name=\"giornata\">
 <option value=\"\">--</option>";
 for ($num1 = "01" ; $num1 < 100 ; $num1++) {
+if (strlen($num1) == 1) $num1 = "0".$num1;
 $giornata = "giornata$num1";
-if (is_dir($giornata)) {
+if (is_file("dati/$giornata")) {
 echo "<option value=\"giornata$num1\">$num1</option>";
 } # fine if (is_dir($giornata))
 else break;
@@ -114,5 +115,5 @@ Ripeti la nuova password: <input type=\"password\" name=\"nuova_pass2\" size=\"9
 
 } # fine else if ($cambia_pass)
 
-include("foot.php");
+include("dati/foot.php");
 ?>
