@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
@@ -48,7 +48,7 @@ $num_giocatori=count($pass);
 reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
 $giocatore = key($pass);
-$soprannome_squadra = @file("squadra_$giocatore");
+$soprannome_squadra = @file("dati/squadra_$giocatore");
 $soprannome_squadra = $soprannome_squadra[3];
 if (!$soprannome_squadra) $soprannome_squadra = "di $giocatore";
 echo "<option value=\"$giocatore\">$soprannome_squadra</option>";
@@ -65,8 +65,9 @@ echo "<td align=\"center\"><form method=\"post\" action=\"guarda_giornata.php\">
  n <select name=\"giornata\">
 <option value=\"\">--</option>";
 for ($num1 = "01" ; $num1 < 100 ; $num1++) {
+if (strlen($num1) == 1) $num1 = "0".$num1;
 $giornata = "giornata$num1";
-if (is_dir($giornata)) {
+if (is_file("dati/$giornata")) {
 echo "<option value=\"giornata$num1\">$num1</option>";
 } # fine if (is_dir($giornata))
 else break;
@@ -74,7 +75,7 @@ else break;
 echo "</select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>";
 } # fine if ($mostra_giornate_in_mercato == "SI")
 if ($num_calciatori_scambiabili > 0) {
-$scambi_proposti = @file("scambi.txt");
+$scambi_proposti = @file("dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
 $dati_scambio = explode(",", $scambi_proposti[$num1]);
@@ -88,7 +89,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti > 0) $richiesto = "SI";
 } # fine if ($nome_utente == $dati_scambio[4])
 } # fine for $num1
@@ -108,7 +109,7 @@ echo "<td align=\"center\"><form method=\"post\" action=\"messaggi.php\">
 </tr></table></td></tr></table>";
 
 
-$calciatori = @file("mercato.txt");
+$calciatori = @file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 
 echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"#b9ccd4\">
@@ -144,7 +145,7 @@ $mese_off = substr($tempo_off,4,2);
 $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) {
 $tempo_restante = "COMPRATO";
 if ($nome_utente == $proprietario) 
@@ -187,7 +188,7 @@ echo "<tr><td>$numero</td>
 echo "$tab_comprati</table>";
 
 $num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
-$surplus = @file("squadra_$nome_utente");
+$surplus = @file("dati/squadra_$nome_utente");
 $surplus = $surplus[0];
 $soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
 if ($num_calciatori_comprabili <= 0 or $soldi_spendibili <= 0) { $offribile = "NO"; }
@@ -205,8 +206,9 @@ echo "<form method=\"post\" action=\"giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
 for ($num1 = "01" ; $num1 < 100 ; $num1++) {
+if (strlen($num1) == 1) $num1 = "0".$num1;
 $giornata = "giornata$num1";
-if (is_dir($giornata)) {
+if (is_file("dati/$giornata")) {
 echo "<input type=\"submit\" name=\"giornata\" value=\"$giornata\">&nbsp;";
 } # fine if (is_dir($giornata))
 else break;
@@ -225,5 +227,5 @@ echo "</form>
 </form></center>";
 } # fine if ($pass_admin_errata == "NO")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
