@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
@@ -29,7 +29,7 @@ if ($aggiungi_messaggio) {
 $nuovo_messaggio = ereg_replace("
 ","",$nuovo_messaggio);
 $nuovo_messaggio = stripslashes($nuovo_messaggio);
-$file_messaggi = fopen("messaggi.txt","a+");
+$file_messaggi = fopen("dati/messaggi.txt","a+");
 flock($file_messaggi,2);
 fwrite($file_messaggi,$nome_utente."#@?".$nuovo_messaggio."
 ");
@@ -41,7 +41,7 @@ fclose($file_messaggi);
 echo "
 <center><font size=+2>Messaggi</font></center>";
 
-$messaggi = @file("messaggi.txt");
+$messaggi = @file("dati/messaggi.txt");
 $num_messaggi = count($messaggi);
 if ($tutti_i_messaggi == "SI") $num_iniziale = 0;
 else $num_iniziale = $num_messaggi - 25;
@@ -89,5 +89,5 @@ echo "<center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
