@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
@@ -39,7 +39,7 @@ echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcol
 <td><font size=-1>Proprietario</font></td>
 <td>__Tempo_rimasto__</td></tr>";
 
-$calciatori = @file("mercato.txt");
+$calciatori = @file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -63,7 +63,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) {
 $tempo_restante = "COMPRATO";
 $offribile = "NO";
@@ -94,7 +94,7 @@ echo"<tr><td>$numero</td>
 } # fine for $num1
 
 if ($trovato != "SI") {
-$calciatori = file("calciatori.txt");
+$calciatori = file("dati/calciatori.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
@@ -166,5 +166,5 @@ echo "<center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
