@@ -1,14 +1,32 @@
-
 <?php
 
-include("head.php");
+##################################################################################
+#    FANTACALCIOBAZAR
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+##################################################################################
+
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
 
 
 
-$calciatori = @file("mercato.txt");
+$calciatori = @file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -26,7 +44,7 @@ echo "<center><font size=+2>Proposte di scambio</font></center><br><font size=-1
 <td><font size=-1>__Tempo_rimasto__</font></td>
 <td><font size=-1>&nbsp;</font></td></tr>";
 
-$scambi_proposti = @file("scambi.txt");
+$scambi_proposti = @file("dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
 
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
@@ -51,7 +69,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 
 if ($sec_restanti > 0) {
 $giorni_restanti = floor($sec_restanti/86400);
@@ -104,5 +122,5 @@ echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
