@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
@@ -44,7 +44,7 @@ $num_calciatori_offerti = 0;
 $num_calciatori_richiesti = 0;
 $lista_ric = "";
 $lista_off = "";
-$calciatori = @file("mercato.txt");
+$calciatori = @file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
@@ -59,7 +59,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 $proprietario = $dati_calciatore[4];
 
 if ($proprietario == $nome_utente) {
@@ -150,14 +150,14 @@ $scambiare = "NO";
 echo "Gli Euro devono essere un numero intero.<br>";
 } # fine if ($verifica_num != "")
 
-$surplus = @file("squadra_$nome_utente");
+$surplus = @file("dati/squadra_$nome_utente");
 $surplus = $surplus[0];
 $soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
 if ($soldi_scambio_utente > $soldi_spendibili) {
 $scambiare = "NO";
 echo "Hai offerto pi soldi di quelli da te posseduti.<br>";
 } # fine if ($soldi_scambio_utente > $soldi_spendibili)
-$surplus_altro = @file("squadra_$altro_utente");
+$surplus_altro = @file("dati/squadra_$altro_utente");
 $surplus_altro = $surplus_altro[0];
 $soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
 if ($soldi_scambio_altro > $soldi_iniziali) {
@@ -166,9 +166,9 @@ echo "Hai richiesto a $altro_utente pi soldi di quelli iniziali.<br>";
 } # fine if ($soldi_scambio_utente > $soldi_spendibili)
 
 if ($scambiare != "NO") {
-$lock = fopen("scambi.lock","w+");
+$lock = fopen("dati/scambi.lock","w+");
 flock($lock,2);
-$scambi_proposti = @file("scambi.txt");
+$scambi_proposti = @file("dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
 $num_offerte_utente = 0;
 $id_scambio = 0;
@@ -185,13 +185,18 @@ echo "Hai gi in corso 12 offerte di scambio.<br>";
 
 # finalmente dopo tutti i controlli inserisco lo scambio
 if ($scambiare != "NO") {
-$file_scambi = fopen("scambi.txt","w+");
+$file_scambi = fopen("dati/scambi.txt","w+");
 flock($file_scambi,2);
-$adesso = date("YmdHi");
+$anno_attuale = date("Y");
+$mese_attuale = date("m");
+$giorno_attuale = date("d");
+$ora_attuale = date("H");
+$minuto_attuale = date("i");
+$scadenza = date("YmdHi",mktime($ora_attuale+$aspetta_ore,$minuto_attuale+$aspetta_minuti,0,$mese_attuale,$giorno_attuale+$aspetta_giorni,$anno_attuale));
 if (!$soldi_scambio_utente) $soldi_scambio_utente = 0;
 if (!$soldi_scambio_altro) $soldi_scambio_altro = 0;
 $id_scambio++;
-$linea = "$id_scambio,$nome_utente,$lista_off,$soldi_scambio_utente,$altro_utente,$lista_ric,$soldi_scambio_altro,$adesso";
+$linea = "$id_scambio,$nome_utente,$lista_off,$soldi_scambio_utente,$altro_utente,$lista_ric,$soldi_scambio_altro,$scadenza";
 fwrite($file_scambi,"$linea
 ");
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
@@ -206,7 +211,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti > 0) fwrite($file_scambi,$scambi_proposti[$num1]);
 } # fine for $num1
 flock($file_scambi,3);
@@ -285,6 +290,6 @@ echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
 
