@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,18 +17,18 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
 
 
 
-$lock = fopen("mercato.lock","w+");
+$lock = fopen("dati/mercato.lock","w+");
 flock($lock,2);
-$lock2 = fopen("scambi.lock","w+");
+$lock2 = fopen("dati/scambi.lock","w+");
 flock($lock2,2);
 
 $trovato = "NO";
@@ -49,7 +49,7 @@ $lista_ric = "";
 $ini_lista_off = "";
 $ini_lista_ric = "";
 
-$scambi_proposti = @file("scambi.txt");
+$scambi_proposti = @file("dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
 
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
@@ -76,7 +76,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) $trovato = "NO";
 break;
 } # fine if ($id_scambio == $dati_scambio[0])
@@ -100,12 +100,12 @@ Sei sicuro di voler accettare lo scambio proposto da <b>$utente_offerente</b>?&n
 else {
 
 
-$lock3 = fopen("squadra_$nome_utente.lock","w+");
+$lock3 = fopen("dati/squadra_$nome_utente.lock","w+");
 flock($lock3,2);
-$lock4 = fopen("squadra_$utente_offerente.lock","w+");
+$lock4 = fopen("dati/squadra_$utente_offerente.lock","w+");
 flock($lock4,2);
 
-$calciatori = @file("mercato.txt");
+$calciatori = @file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
@@ -120,7 +120,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 $proprietario = $dati_calciatore[4];
 
 if ($proprietario == $nome_utente) {
@@ -174,14 +174,14 @@ $scambiare = "NO";
 echo "Dopo lo scambio $utente_offerente avrebbe pi di $max_calciatori calciatori.<br>";
 } # fine if ($num_calciatori_dopo > $max_calciatori)
 
-$surplus = @file("squadra_$nome_utente");
+$surplus = @file("dati/squadra_$nome_utente");
 $surplus = $surplus[0];
 $soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
 if ($soldi_richiesti > $soldi_spendibili) {
 $scambiare = "NO";
 echo "Ti sono richiesti pi soldi di quelli da te posseduti.<br>";
 } # fine if ($soldi_richiesti > $soldi_spendibili)
-$surplus_altro = @file("squadra_$utente_offerente");
+$surplus_altro = @file("dati/squadra_$utente_offerente");
 $surplus_altro = $surplus_altro[0];
 $soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
 if ($soldi_offerti > $soldi_spendibili_altro) {
@@ -192,7 +192,7 @@ echo "I soldi offerti sono pi di quelli posseduti da $utente_offerente.<br>";
 # se i controlli sono andati bene effettuo lo scambio
 if ($scambiare != "NO") {
 
-$file_mercato = fopen("mercato.txt","w+");
+$file_mercato = fopen("dati/mercato.txt","w+");
 flock($file_mercato,2);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -236,8 +236,8 @@ flock($file_mercato,3);
 fclose($file_mercato);
 
 $aggiungi_surplus = $costo_calciatori_offerti - $costo_calciatori_richiesti + $soldi_offerti - $soldi_richiesti;
-$linee = @file("squadra_$nome_utente");
-$filesquadra = fopen("squadra_$nome_utente","w+");
+$linee = @file("dati/squadra_$nome_utente");
+$filesquadra = fopen("dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
@@ -252,8 +252,8 @@ flock($filesquadra,3);
 fclose($filesquadra);
 
 $aggiungi_surplus = $costo_calciatori_richiesti - $costo_calciatori_offerti + $soldi_richiesti - $soldi_offerti;
-$linee = @file("squadra_$utente_offerente");
-$filesquadra = fopen("squadra_$utente_offerente","w+");
+$linee = @file("dati/squadra_$utente_offerente");
+$filesquadra = fopen("dati/squadra_$utente_offerente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
@@ -267,9 +267,9 @@ fwrite($filesquadra,$linee[$num1]);
 flock($filesquadra,3);
 fclose($filesquadra);
 
-$scambi_proposti = @file("scambi.txt");
+$scambi_proposti = @file("dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
-$file_scambi = fopen("scambi.txt","w+");
+$file_scambi = fopen("dati/scambi.txt","w+");
 flock($file_scambi,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
@@ -283,7 +283,7 @@ $mese_off = substr($tempo_off,4,2);
 $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti > 0 and $id_scambio != $dati_scambio[0]) fwrite($file_scambi,$scambi_proposti[$num1]);
 } # fine for $num1
 flock($file_scambi,3);
@@ -292,7 +292,7 @@ fclose($file_scambi);
 if ($soldi_richiesti != 0) $lista_ric .= " + $soldi_richiesti Euro";
 if ($soldi_offerti != 0) $lista_off .= " + $soldi_offerti Euro";
 $nuovo_messaggio = "$nome_utente ha accettato lo scambio proposto da $utente_offerente per $lista_ric in cambio di $lista_off";
-$file_messaggi = fopen("messaggi.txt","a+");
+$file_messaggi = fopen("dati/messaggi.txt","a+");
 flock($file_messaggi,2);
 fwrite($file_messaggi,"Radio mercato#@?".$nuovo_messaggio."
 ");
@@ -329,5 +329,5 @@ echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
\ No newline at end of file
