@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
@@ -37,7 +37,7 @@ $num_titolari_A = 0;
 $num_panchinari = 0;
 $num_in_panchina_usati = "";
 
-$calciatori = file("mercato.txt");
+$calciatori = file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -52,7 +52,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) {
 $nome_schierato = "schierato$numero";
 if ($$nome_schierato == "titolare") {
@@ -133,10 +133,10 @@ if ($num_titolari_A > $max_num_cons_A) { $inserire = "NO"; $frase .= "Troppi att
 } # fine if ($num_titolari < 11)
 
 if ($inserire != "NO") {
-$lock = fopen("squadra_$nome_utente.lock","w+");
+$lock = fopen("dati/squadra_$nome_utente.lock","w+");
 flock($lock,2);
-$linee = @file("squadra_$nome_utente");
-$filesquadra = fopen("squadra_$nome_utente","w+");
+$linee = @file("dati/squadra_$nome_utente");
+$filesquadra = fopen("dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 3) { $num_linee = 3; }
