@@ -1,8 +1,8 @@
 <?php
 
-################################################################################
+##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-################################################################################
+##################################################################################
 
-include("head.php");
+include("dati/head.php");
 
 include("controlla_pass.php");
 if ($pass_errata != "SI") {
@@ -31,16 +31,16 @@ $num_giocatori=count($pass);
 reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
 $giocatore = key($pass);
-$soprannome_squadra = @file("squadra_$giocatore");
+$soprannome_squadra = @file("dati/squadra_$giocatore");
 $soprannome_squadra = $soprannome_squadra[3];
 if ($nuovo_soprannome == $soprannome_squadra) $inserire = "NO";
 next($pass);
 } # fine for $num1
 if (strlen($nuovo_soprannome) <= 20 and $inserire != "NO") {
-$lock = fopen("squadra_$nome_utente.lock","w+");
+$lock = fopen("dati/squadra_$nome_utente.lock","w+");
 flock($lock,2);
-$linee = @file("squadra_$nome_utente");
-$filesquadra = fopen("squadra_$nome_utente","w+");
+$linee = @file("dati/squadra_$nome_utente");
+$filesquadra = fopen("dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 4) { $num_linee = 4; }
@@ -77,7 +77,7 @@ $giocatore = key($pass);
 
 if ($nome_squadra == $giocatore or $nome_squadra == "tutti") {
 
-$dati_squadra = @file("squadra_$giocatore");
+$dati_squadra = @file("dati/squadra_$giocatore");
 $soprannome_squadra = $dati_squadra[3];
 $soprannome_squadra = ereg_replace("
 ","",$soprannome_squadra);
@@ -102,7 +102,7 @@ $tab_offerte = "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"cent
 <td><font size=-1>Costo</font></td>
 <td>__Tempo_rimasto__</td></tr>";
 
-$calciatori = @file("mercato.txt");
+$calciatori = @file("dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num2 = 0 ; $num2 < $num_calciatori ; $num2++) {
 $dati_calciatore = explode(",", $calciatori[$num2]);
@@ -121,7 +121,7 @@ $giorno_off = substr($tempo_off,6,2);
 $ora_off = substr($tempo_off,8,2);
 $minuto_off = substr($tempo_off,10,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
-$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
+$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) {
 $lista_calciatori[$contatore_calciatori] = $numero;
 $contatore_calciatori++;
@@ -325,7 +325,7 @@ echo "<center><br>
 } # fine if ($giocatore == $nome_utente)
 
 $num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
-$surplus = @file("squadra_$giocatore");
+$surplus = @file("dati/squadra_$giocatore");
 $surplus = $surplus[0];
 $soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
 echo "Soldi ancora da spendere: <b>$soldi_spendibili</b> Euro.<br>
@@ -354,7 +354,7 @@ echo "<center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("foot.php");
+include("dati/foot.php");
 ?>
 
 
